@@ -13,7 +13,7 @@
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
+   along with this library; see the file COPYING.LGPL-2.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
@@ -673,7 +673,9 @@ void KRichTextWidget::mouseReleaseEvent(QMouseEvent *event)
         // If the painter is active, paint the selection with the
         // correct format.
         if (textCursor().hasSelection()) {
-            textCursor().setCharFormat(d->painterFormat);
+            QTextCursor c = textCursor();
+            c.setCharFormat(d->painterFormat);
+            setTextCursor(c);
         }
         d->painterActive = false;
         d->action_format_painter->setChecked(false);
